#[non_exhaustive]pub enum MetricsRecvError {
Empty,
Timeout,
Closed,
}Expand description
Reason a non-blocking or timed metrics receive did not return an event.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
No event was currently queued.
Timeout
No event arrived before the requested timeout elapsed.
Closed
The iperf run has ended and no more events can arrive.