#[non_exhaustive]pub enum TransportProtocol {
Unknown,
Tcp,
Udp,
Sctp,
Other(i32),
}Expand description
Transport protocol selected by libiperf for a metrics sample.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
The protocol was not reported or is not currently recognized.
Tcp
TCP mode.
Udp
UDP mode.
Sctp
SCTP mode.
Other(i32)
Another upstream protocol id.