PushGatewayConfig

Struct PushGatewayConfig 

#[non_exhaustive]
pub struct PushGatewayConfig { pub endpoint: Url, pub job: String, pub labels: Vec<(String, String)>, pub timeout: Duration, pub retries: u32, pub user_agent: String, pub metric_prefix: String, pub delete_on_finish: bool, }
Configuration for a PushGateway sink.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
endpoint: Url

Base Pushgateway URL.

The final request path is built as /metrics/job/{job}/{label}/{value}/....

job: String

Pushgateway job name.

labels: Vec<(String, String)>

Grouping labels encoded into the Pushgateway request path.

timeout: Duration

Per-request HTTP timeout.

retries: u32

Number of retries after the first failed request.

user_agent: String

HTTP User-Agent header.

metric_prefix: String

Prefix for emitted Prometheus metric names.

delete_on_finish: bool

Delete this grouping key from Pushgateway after the run finishes.

Implementations

Source

impl PushGatewayConfig

pub const DEFAULT_JOB: &'static str = "iperf3"

Default Pushgateway job name used by the CLI and builder.

pub const DEFAULT_METRIC_PREFIX: &'static str = PrometheusEncoder::DEFAULT_PREFIX

Default metric prefix used by the CLI and builder.

pub const DEFAULT_RETRIES: u32 = 0

Default number of Pushgateway retries after the first failed request.

pub const MAX_RETRIES: u32 = 10

Maximum supported retry count.

pub fn new(endpoint: Url) -> Self

Build a config with production-safe defaults for every field except the Pushgateway endpoint.

pub fn parse_endpoint(raw: &str) -> Result<Url>

Parse a Pushgateway endpoint, defaulting bare host:port values to HTTP.

pub const fn default_timeout() -> Duration

Default per-request timeout.

pub fn default_user_agent() -> String

Default HTTP User-Agent.

pub fn job(self, job: impl Into<String>) -> Self

Set the Pushgateway job name.

pub fn label(self, name: impl Into<String>, value: impl Into<String>) -> Self

Add one grouping label.

pub fn labels<I, K, V>(self, labels: I) -> Self
where I: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Replace grouping labels.

pub fn timeout(self, timeout: Duration) -> Self

Set the per-request HTTP timeout.

pub fn retries(self, retries: u32) -> Self

Set the number of retries after the first failed request.

pub fn user_agent(self, user_agent: impl Into<String>) -> Self

Set the HTTP User-Agent.

pub fn metric_prefix(self, metric_prefix: impl Into<String>) -> Self

Set the Prometheus metric name prefix.

pub fn delete_on_finish(self, delete: bool) -> Self

Delete this grouping key from Pushgateway after direct delivery finishes.

pub fn validate(&self) -> Result<()>

Validate this config before it is used for HTTP delivery.