#[non_exhaustive]pub struct WindowMetrics {Show 20 fields
pub timestamp_unix_seconds: f64,
pub role: Role,
pub direction: MetricDirection,
pub stream_count: usize,
pub protocol: TransportProtocol,
pub duration_seconds: f64,
pub transferred_bytes: f64,
pub bandwidth_bits_per_second: WindowGaugeStats,
pub tcp_rtt_seconds: WindowGaugeStats,
pub tcp_rttvar_seconds: WindowGaugeStats,
pub tcp_snd_cwnd_bytes: WindowGaugeStats,
pub tcp_snd_wnd_bytes: WindowGaugeStats,
pub tcp_pmtu_bytes: WindowGaugeStats,
pub udp_jitter_seconds: WindowGaugeStats,
pub tcp_retransmits: Option<f64>,
pub tcp_reorder_events: Option<f64>,
pub udp_packets: Option<f64>,
pub udp_lost_packets: Option<f64>,
pub udp_out_of_order_packets: Option<f64>,
pub omitted_intervals: f64,
}Expand description
Summary of one aggregated metrics window.
Counter-like fields are accumulated across the window. Gauge-like fields use
WindowGaugeStats.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timestamp_unix_seconds: f64Unix timestamp, in seconds, of the last interval sample in this window.
role: RoleRole of the iperf test that produced this window.
direction: MetricDirectionSender/receiver direction represented by this window.
stream_count: usizeNumber of libiperf streams represented by this window.
protocol: TransportProtocolTransport protocol used by this window.
duration_seconds: f64Total interval duration represented by this window.
transferred_bytes: f64Total bytes transferred across this window.
bandwidth_bits_per_second: WindowGaugeStatsBandwidth statistics in bits per second.
tcp_rtt_seconds: WindowGaugeStatsTCP smoothed RTT statistics in seconds.
tcp_rttvar_seconds: WindowGaugeStatsTCP RTT variance statistics in seconds.
tcp_snd_cwnd_bytes: WindowGaugeStatsTCP sender congestion window statistics in bytes.
tcp_snd_wnd_bytes: WindowGaugeStatsTCP sender window statistics in bytes.
tcp_pmtu_bytes: WindowGaugeStatsTCP path MTU statistics in bytes.
udp_jitter_seconds: WindowGaugeStatsUDP jitter statistics in seconds.
tcp_retransmits: Option<f64>TCP retransmits accumulated across the window.
tcp_reorder_events: Option<f64>TCP reordering events accumulated across the window.
udp_packets: Option<f64>UDP packet count accumulated across the window.
udp_lost_packets: Option<f64>UDP lost packet count accumulated across the window.
udp_out_of_order_packets: Option<f64>UDP out-of-order packet count accumulated across the window.
omitted_intervals: f64Number of omitted libiperf intervals in the window.
Implementations
Sourceimpl WindowMetrics
impl WindowMetrics